@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2013 Bastian Kleineidam
+# Copyright (C) 2010-2014 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -226,10 +226,10 @@ ArchivePrograms = {
         None: ('lzop',),
     },
     'lzma': {
-        'extract': ('7z', 'lzma') + py_lzma,
+        'extract': ('7z', 'lzma', 'xz') + py_lzma,
         'list': ('7z', 'py_echo'),
-        'test': ('7z', 'lzma'),
-        'create': ('lzma',) + py_lzma,
+        'test': ('7z', 'lzma', 'xz'),
+        'create': ('lzma', 'xz') + py_lzma,
     },
     'rzip': {
         'extract': ('rzip',),
@@ -385,7 +385,7 @@ def move_outdir_orphan (outdir):
     if len(entries) == 1:
         src = os.path.join(outdir, entries[0])
         dst = os.path.join(os.path.dirname(outdir), entries[0])
-        if os.path.exists(dst):
+        if os.path.exists(dst) or os.path.islink(dst):
             return (False, "local file exists")
         shutil.move(src, dst)
         os.rmdir(outdir)
