@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2013 Bastian Kleineidam
+# Copyright (C) 2010-2014 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -124,6 +124,8 @@ class TestMime (unittest.TestCase):
         self.mime_test_file("t.chm", "application/x-chm")
         self.mime_test_file("t.chm.foo", "application/x-chm")
         self.mime_test_file("t.iso", "application/x-iso9660-image")
+        self.mime_test_file("t.epub", "application/zip")
+        self.mime_test_file("t.apk", "application/zip")
 
     @needs_program('file')
     @needs_program('lzip')
@@ -198,3 +200,5 @@ class TestMime (unittest.TestCase):
         self.mime_test_mimedb("t.adf", "application/x-adf")
         self.mime_test_mimedb("t.chm", "application/x-chm")
         self.mime_test_mimedb("t.iso", "application/x-iso9660-image")
+        self.mime_test_mimedb("t.epub", "application/zip")
+        self.mime_test_mimedb("t.apk", "application/zip")
